Class: Aws::LexModelBuildingService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LexModelBuildingService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lexmodelbuildingservice/client.rb
Overview
An API client for LexModelBuildingService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::LexModelBuildingService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_bot_version(params = {}) ⇒ Types::CreateBotVersionResponse
Creates a new version of the bot based on the ‘$LATEST` version.
-
#create_intent_version(params = {}) ⇒ Types::CreateIntentVersionResponse
Creates a new version of an intent based on the ‘$LATEST` version of the intent.
-
#create_slot_type_version(params = {}) ⇒ Types::CreateSlotTypeVersionResponse
Creates a new version of a slot type based on the ‘$LATEST` version of the specified slot type.
-
#delete_bot(params = {}) ⇒ Struct
Deletes all versions of the bot, including the ‘$LATEST` version.
-
#delete_bot_alias(params = {}) ⇒ Struct
Deletes an alias for the specified bot.
-
#delete_bot_channel_association(params = {}) ⇒ Struct
Deletes the association between an Amazon Lex bot and a messaging platform.
-
#delete_bot_version(params = {}) ⇒ Struct
Deletes a specific version of a bot.
-
#delete_intent(params = {}) ⇒ Struct
Deletes all versions of the intent, including the ‘$LATEST` version.
-
#delete_intent_version(params = {}) ⇒ Struct
Deletes a specific version of an intent.
-
#delete_slot_type(params = {}) ⇒ Struct
Deletes all versions of the slot type, including the ‘$LATEST` version.
-
#delete_slot_type_version(params = {}) ⇒ Struct
Deletes a specific version of a slot type.
-
#delete_utterances(params = {}) ⇒ Struct
Deletes stored utterances.
-
#get_bot(params = {}) ⇒ Types::GetBotResponse
Returns metadata information for a specific bot.
-
#get_bot_alias(params = {}) ⇒ Types::GetBotAliasResponse
Returns information about an Amazon Lex bot alias.
-
#get_bot_aliases(params = {}) ⇒ Types::GetBotAliasesResponse
Returns a list of aliases for a specified Amazon Lex bot.
-
#get_bot_channel_association(params = {}) ⇒ Types::GetBotChannelAssociationResponse
Returns information about the association between an Amazon Lex bot and a messaging platform.
-
#get_bot_channel_associations(params = {}) ⇒ Types::GetBotChannelAssociationsResponse
Returns a list of all of the channels associated with the specified bot.
-
#get_bot_versions(params = {}) ⇒ Types::GetBotVersionsResponse
Gets information about all of the versions of a bot.
-
#get_bots(params = {}) ⇒ Types::GetBotsResponse
Returns bot information as follows:.
-
#get_builtin_intent(params = {}) ⇒ Types::GetBuiltinIntentResponse
Returns information about a built-in intent.
-
#get_builtin_intents(params = {}) ⇒ Types::GetBuiltinIntentsResponse
Gets a list of built-in intents that meet the specified criteria.
-
#get_builtin_slot_types(params = {}) ⇒ Types::GetBuiltinSlotTypesResponse
Gets a list of built-in slot types that meet the specified criteria.
-
#get_export(params = {}) ⇒ Types::GetExportResponse
Exports the contents of a Amazon Lex resource in a specified format.
-
#get_import(params = {}) ⇒ Types::GetImportResponse
Gets information about an import job started with the ‘StartImport` operation.
-
#get_intent(params = {}) ⇒ Types::GetIntentResponse
Returns information about an intent.
-
#get_intent_versions(params = {}) ⇒ Types::GetIntentVersionsResponse
Gets information about all of the versions of an intent.
-
#get_intents(params = {}) ⇒ Types::GetIntentsResponse
Returns intent information as follows:.
-
#get_migration(params = {}) ⇒ Types::GetMigrationResponse
Provides details about an ongoing or complete migration from an Amazon Lex V1 bot to an Amazon Lex V2 bot.
-
#get_migrations(params = {}) ⇒ Types::GetMigrationsResponse
Gets a list of migrations between Amazon Lex V1 and Amazon Lex V2.
-
#get_slot_type(params = {}) ⇒ Types::GetSlotTypeResponse
Returns information about a specific version of a slot type.
-
#get_slot_type_versions(params = {}) ⇒ Types::GetSlotTypeVersionsResponse
Gets information about all versions of a slot type.
-
#get_slot_types(params = {}) ⇒ Types::GetSlotTypesResponse
Returns slot type information as follows:.
-
#get_utterances_view(params = {}) ⇒ Types::GetUtterancesViewResponse
Use the ‘GetUtterancesView` operation to get information about the utterances that your users have made to your bot.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with the specified resource.
-
#put_bot(params = {}) ⇒ Types::PutBotResponse
Creates an Amazon Lex conversational bot or replaces an existing bot.
-
#put_bot_alias(params = {}) ⇒ Types::PutBotAliasResponse
Creates an alias for the specified version of the bot or replaces an alias for the specified bot.
-
#put_intent(params = {}) ⇒ Types::PutIntentResponse
Creates an intent or replaces an existing intent.
-
#put_slot_type(params = {}) ⇒ Types::PutSlotTypeResponse
Creates a custom slot type or replaces an existing custom slot type.
-
#start_import(params = {}) ⇒ Types::StartImportResponse
Starts a job to import a resource to Amazon Lex.
-
#start_migration(params = {}) ⇒ Types::StartMigrationResponse
Starts migrating a bot from Amazon Lex V1 to Amazon Lex V2.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a bot, bot alias or bot channel.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4537 4538 4539 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4537 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4540 4541 4542 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4540 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4510 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LexModelBuildingService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-lexmodelbuildingservice' context[:gem_version] = '1.106.0' Seahorse::Client::Request.new(handlers, context) end |
#create_bot_version(params = {}) ⇒ Types::CreateBotVersionResponse
Creates a new version of the bot based on the ‘$LATEST` version. If the `$LATEST` version of this resource hasn’t changed since you created the last version, Amazon Lex doesn’t create a new version. It returns the last created version.
<note markdown=“1”> You can update only the ‘$LATEST` version of the bot. You can’t update the numbered versions that you create with the ‘CreateBotVersion` operation.
</note>
When you create the first version of a bot, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see versioning-intro.
This operation requires permission for the ‘lex:CreateBotVersion` action.
568 569 570 571 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 568 def create_bot_version(params = {}, = {}) req = build_request(:create_bot_version, params) req.send_request() end |
#create_intent_version(params = {}) ⇒ Types::CreateIntentVersionResponse
Creates a new version of an intent based on the ‘$LATEST` version of the intent. If the `$LATEST` version of this intent hasn’t changed since you last updated it, Amazon Lex doesn’t create a new version. It returns the last version you created.
<note markdown=“1”> You can update only the ‘$LATEST` version of the intent. You can’t update the numbered versions that you create with the ‘CreateIntentVersion` operation.
</note>
When you create a version of an intent, Amazon Lex sets the version to
-
Subsequent versions increment by 1. For more information, see
versioning-intro.
This operation requires permissions to perform the ‘lex:CreateIntentVersion` action.
707 708 709 710 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 707 def create_intent_version(params = {}, = {}) req = build_request(:create_intent_version, params) req.send_request() end |
#create_slot_type_version(params = {}) ⇒ Types::CreateSlotTypeVersionResponse
Creates a new version of a slot type based on the ‘$LATEST` version of the specified slot type. If the `$LATEST` version of this resource has not changed since the last version that you created, Amazon Lex doesn’t create a new version. It returns the last version that you created.
<note markdown=“1”> You can update only the ‘$LATEST` version of a slot type. You can’t update the numbered versions that you create with the ‘CreateSlotTypeVersion` operation.
</note>
When you create a version of a slot type, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see versioning-intro.
This operation requires permissions for the ‘lex:CreateSlotTypeVersion` action.
784 785 786 787 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 784 def create_slot_type_version(params = {}, = {}) req = build_request(:create_slot_type_version, params) req.send_request() end |
#delete_bot(params = {}) ⇒ Struct
Deletes all versions of the bot, including the ‘$LATEST` version. To delete a specific version of the bot, use the DeleteBotVersion operation. The `DeleteBot` operation doesn’t immediately remove the bot schema. Instead, it is marked for deletion and removed later.
Amazon Lex stores utterances indefinitely for improving the ability of your bot to respond to user inputs. These utterances are not removed when the bot is deleted. To remove the utterances, use the DeleteUtterances operation.
If a bot has an alias, you can’t delete it. Instead, the ‘DeleteBot` operation returns a `ResourceInUseException` exception that includes a reference to the alias that refers to the bot. To remove the reference to the bot, delete the alias. If you get the same exception again, delete the referring alias until the `DeleteBot` operation is successful.
This operation requires permissions for the ‘lex:DeleteBot` action.
823 824 825 826 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 823 def delete_bot(params = {}, = {}) req = build_request(:delete_bot, params) req.send_request() end |
#delete_bot_alias(params = {}) ⇒ Struct
Deletes an alias for the specified bot.
You can’t delete an alias that is used in the association between a bot and a messaging channel. If an alias is used in a channel association, the ‘DeleteBot` operation returns a `ResourceInUseException` exception that includes a reference to the channel association that refers to the bot. You can remove the reference to the alias by deleting the channel association. If you get the same exception again, delete the referring association until the `DeleteBotAlias` operation is successful.
858 859 860 861 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 858 def delete_bot_alias(params = {}, = {}) req = build_request(:delete_bot_alias, params) req.send_request() end |
#delete_bot_channel_association(params = {}) ⇒ Struct
Deletes the association between an Amazon Lex bot and a messaging platform.
This operation requires permission for the ‘lex:DeleteBotChannelAssociation` action.
893 894 895 896 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 893 def delete_bot_channel_association(params = {}, = {}) req = build_request(:delete_bot_channel_association, params) req.send_request() end |
#delete_bot_version(params = {}) ⇒ Struct
Deletes a specific version of a bot. To delete all versions of a bot, use the DeleteBot operation.
This operation requires permissions for the ‘lex:DeleteBotVersion` action.
925 926 927 928 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 925 def delete_bot_version(params = {}, = {}) req = build_request(:delete_bot_version, params) req.send_request() end |
#delete_intent(params = {}) ⇒ Struct
Deletes all versions of the intent, including the ‘$LATEST` version. To delete a specific version of the intent, use the DeleteIntentVersion operation.
You can delete a version of an intent only if it is not referenced. To delete an intent that is referred to in one or more bots (see how-it-works), you must remove those references first.
<note markdown=“1”> If you get the ‘ResourceInUseException` exception, it provides an example reference that shows where the intent is referenced. To remove the reference to the intent, either update the bot or delete it. If you get the same exception when you attempt to delete the intent again, repeat until the intent has no references and the call to `DeleteIntent` is successful.
</note>
This operation requires permission for the ‘lex:DeleteIntent` action.
964 965 966 967 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 964 def delete_intent(params = {}, = {}) req = build_request(:delete_intent, params) req.send_request() end |
#delete_intent_version(params = {}) ⇒ Struct
Deletes a specific version of an intent. To delete all versions of a intent, use the DeleteIntent operation.
This operation requires permissions for the ‘lex:DeleteIntentVersion` action.
996 997 998 999 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 996 def delete_intent_version(params = {}, = {}) req = build_request(:delete_intent_version, params) req.send_request() end |
#delete_slot_type(params = {}) ⇒ Struct
Deletes all versions of the slot type, including the ‘$LATEST` version. To delete a specific version of the slot type, use the DeleteSlotTypeVersion operation.
You can delete a version of a slot type only if it is not referenced. To delete a slot type that is referred to in one or more intents, you must remove those references first.
<note markdown=“1”> If you get the ‘ResourceInUseException` exception, the exception provides an example reference that shows the intent where the slot type is referenced. To remove the reference to the slot type, either update the intent or delete it. If you get the same exception when you attempt to delete the slot type again, repeat until the slot type has no references and the `DeleteSlotType` call is successful.
</note>
This operation requires permission for the ‘lex:DeleteSlotType` action.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1036 def delete_slot_type(params = {}, = {}) req = build_request(:delete_slot_type, params) req.send_request() end |
#delete_slot_type_version(params = {}) ⇒ Struct
Deletes a specific version of a slot type. To delete all versions of a slot type, use the DeleteSlotType operation.
This operation requires permissions for the ‘lex:DeleteSlotTypeVersion` action.
1068 1069 1070 1071 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1068 def delete_slot_type_version(params = {}, = {}) req = build_request(:delete_slot_type_version, params) req.send_request() end |
#delete_utterances(params = {}) ⇒ Struct
Deletes stored utterances.
Amazon Lex stores the utterances that users send to your bot. Utterances are stored for 15 days for use with the GetUtterancesView operation, and then stored indefinitely for use in improving the ability of your bot to respond to user input.
Use the ‘DeleteUtterances` operation to manually delete stored utterances for a specific user. When you use the `DeleteUtterances` operation, utterances stored for improving your bot’s ability to respond to user input are deleted immediately. Utterances stored for use with the ‘GetUtterancesView` operation are deleted after 15 days.
This operation requires permissions for the ‘lex:DeleteUtterances` action.
1115 1116 1117 1118 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1115 def delete_utterances(params = {}, = {}) req = build_request(:delete_utterances, params) req.send_request() end |
#get_bot(params = {}) ⇒ Types::GetBotResponse
Returns metadata information for a specific bot. You must provide the bot name and the bot version or alias.
This operation requires permissions for the ‘lex:GetBot` action.
1250 1251 1252 1253 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1250 def get_bot(params = {}, = {}) req = build_request(:get_bot, params) req.send_request() end |
#get_bot_alias(params = {}) ⇒ Types::GetBotAliasResponse
Returns information about an Amazon Lex bot alias. For more information about aliases, see versioning-aliases.
This operation requires permissions for the ‘lex:GetBotAlias` action.
1305 1306 1307 1308 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1305 def get_bot_alias(params = {}, = {}) req = build_request(:get_bot_alias, params) req.send_request() end |
#get_bot_aliases(params = {}) ⇒ Types::GetBotAliasesResponse
Returns a list of aliases for a specified Amazon Lex bot.
This operation requires permissions for the ‘lex:GetBotAliases` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1372 1373 1374 1375 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1372 def get_bot_aliases(params = {}, = {}) req = build_request(:get_bot_aliases, params) req.send_request() end |
#get_bot_channel_association(params = {}) ⇒ Types::GetBotChannelAssociationResponse
Returns information about the association between an Amazon Lex bot and a messaging platform.
This operation requires permissions for the ‘lex:GetBotChannelAssociation` action.
1431 1432 1433 1434 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1431 def get_bot_channel_association(params = {}, = {}) req = build_request(:get_bot_channel_association, params) req.send_request() end |
#get_bot_channel_associations(params = {}) ⇒ Types::GetBotChannelAssociationsResponse
Returns a list of all of the channels associated with the specified bot.
The ‘GetBotChannelAssociations` operation requires permissions for the `lex:GetBotChannelAssociations` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1502 1503 1504 1505 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1502 def get_bot_channel_associations(params = {}, = {}) req = build_request(:get_bot_channel_associations, params) req.send_request() end |
#get_bot_versions(params = {}) ⇒ Types::GetBotVersionsResponse
Gets information about all of the versions of a bot.
The ‘GetBotVersions` operation returns a `BotMetadata` object for each version of a bot. For example, if a bot has three numbered versions, the `GetBotVersions` operation returns four `BotMetadata` objects in the response, one for each numbered version and one for the `$LATEST` version.
The ‘GetBotVersions` operation always returns at least one version, the `$LATEST` version.
This operation requires permissions for the ‘lex:GetBotVersions` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1564 1565 1566 1567 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1564 def get_bot_versions(params = {}, = {}) req = build_request(:get_bot_versions, params) req.send_request() end |
#get_bots(params = {}) ⇒ Types::GetBotsResponse
Returns bot information as follows:
-
If you provide the ‘nameContains` field, the response includes information for the `$LATEST` version of all bots whose name contains the specified string.
-
If you don’t specify the ‘nameContains` field, the operation returns information about the `$LATEST` version of all of your bots.
This operation requires permission for the ‘lex:GetBots` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1649 1650 1651 1652 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1649 def get_bots(params = {}, = {}) req = build_request(:get_bots, params) req.send_request() end |
#get_builtin_intent(params = {}) ⇒ Types::GetBuiltinIntentResponse
Returns information about a built-in intent.
This operation requires permission for the ‘lex:GetBuiltinIntent` action.
1692 1693 1694 1695 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1692 def get_builtin_intent(params = {}, = {}) req = build_request(:get_builtin_intent, params) req.send_request() end |
#get_builtin_intents(params = {}) ⇒ Types::GetBuiltinIntentsResponse
Gets a list of built-in intents that meet the specified criteria.
This operation requires permission for the ‘lex:GetBuiltinIntents` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1754 1755 1756 1757 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1754 def get_builtin_intents(params = {}, = {}) req = build_request(:get_builtin_intents, params) req.send_request() end |
#get_builtin_slot_types(params = {}) ⇒ Types::GetBuiltinSlotTypesResponse
Gets a list of built-in slot types that meet the specified criteria.
For a list of built-in slot types, see [Slot Type Reference] in the *Alexa Skills Kit*.
This operation requires permission for the ‘lex:GetBuiltInSlotTypes` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1817 1818 1819 1820 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1817 def get_builtin_slot_types(params = {}, = {}) req = build_request(:get_builtin_slot_types, params) req.send_request() end |
#get_export(params = {}) ⇒ Types::GetExportResponse
Exports the contents of a Amazon Lex resource in a specified format.
1869 1870 1871 1872 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1869 def get_export(params = {}, = {}) req = build_request(:get_export, params) req.send_request() end |
#get_import(params = {}) ⇒ Types::GetImportResponse
Gets information about an import job started with the ‘StartImport` operation.
1911 1912 1913 1914 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 1911 def get_import(params = {}, = {}) req = build_request(:get_import, params) req.send_request() end |
#get_intent(params = {}) ⇒ Types::GetIntentResponse
Returns information about an intent. In addition to the intent name, you must specify the intent version.
This operation requires permissions to perform the ‘lex:GetIntent` action.
2177 2178 2179 2180 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2177 def get_intent(params = {}, = {}) req = build_request(:get_intent, params) req.send_request() end |
#get_intent_versions(params = {}) ⇒ Types::GetIntentVersionsResponse
Gets information about all of the versions of an intent.
The ‘GetIntentVersions` operation returns an `IntentMetadata` object for each version of an intent. For example, if an intent has three numbered versions, the `GetIntentVersions` operation returns four `IntentMetadata` objects in the response, one for each numbered version and one for the `$LATEST` version.
The ‘GetIntentVersions` operation always returns at least one version, the `$LATEST` version.
This operation requires permissions for the ‘lex:GetIntentVersions` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2238 2239 2240 2241 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2238 def get_intent_versions(params = {}, = {}) req = build_request(:get_intent_versions, params) req.send_request() end |
#get_intents(params = {}) ⇒ Types::GetIntentsResponse
Returns intent information as follows:
-
If you specify the ‘nameContains` field, returns the `$LATEST` version of all intents that contain the specified string.
-
If you don’t specify the ‘nameContains` field, returns information about the `$LATEST` version of all intents.
The operation requires permission for the ‘lex:GetIntents` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2320 2321 2322 2323 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2320 def get_intents(params = {}, = {}) req = build_request(:get_intents, params) req.send_request() end |
#get_migration(params = {}) ⇒ Types::GetMigrationResponse
Provides details about an ongoing or complete migration from an Amazon Lex V1 bot to an Amazon Lex V2 bot. Use this operation to view the migration alerts and warnings related to the migration.
2375 2376 2377 2378 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2375 def get_migration(params = {}, = {}) req = build_request(:get_migration, params) req.send_request() end |
#get_migrations(params = {}) ⇒ Types::GetMigrationsResponse
Gets a list of migrations between Amazon Lex V1 and Amazon Lex V2.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2443 2444 2445 2446 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2443 def get_migrations(params = {}, = {}) req = build_request(:get_migrations, params) req.send_request() end |
#get_slot_type(params = {}) ⇒ Types::GetSlotTypeResponse
Returns information about a specific version of a slot type. In addition to specifying the slot type name, you must specify the slot type version.
This operation requires permissions for the ‘lex:GetSlotType` action.
2529 2530 2531 2532 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2529 def get_slot_type(params = {}, = {}) req = build_request(:get_slot_type, params) req.send_request() end |
#get_slot_type_versions(params = {}) ⇒ Types::GetSlotTypeVersionsResponse
Gets information about all versions of a slot type.
The ‘GetSlotTypeVersions` operation returns a `SlotTypeMetadata` object for each version of a slot type. For example, if a slot type has three numbered versions, the `GetSlotTypeVersions` operation returns four `SlotTypeMetadata` objects in the response, one for each numbered version and one for the `$LATEST` version.
The ‘GetSlotTypeVersions` operation always returns at least one version, the `$LATEST` version.
This operation requires permissions for the ‘lex:GetSlotTypeVersions` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2590 2591 2592 2593 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2590 def get_slot_type_versions(params = {}, = {}) req = build_request(:get_slot_type_versions, params) req.send_request() end |
#get_slot_types(params = {}) ⇒ Types::GetSlotTypesResponse
Returns slot type information as follows:
-
If you specify the ‘nameContains` field, returns the `$LATEST` version of all slot types that contain the specified string.
-
If you don’t specify the ‘nameContains` field, returns information about the `$LATEST` version of all slot types.
The operation requires permission for the ‘lex:GetSlotTypes` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2686 2687 2688 2689 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2686 def get_slot_types(params = {}, = {}) req = build_request(:get_slot_types, params) req.send_request() end |
#get_utterances_view(params = {}) ⇒ Types::GetUtterancesViewResponse
Use the ‘GetUtterancesView` operation to get information about the utterances that your users have made to your bot. You can use this list to tune the utterances that your bot responds to.
For example, say that you have created a bot to order flowers. After your users have used your bot for a while, use the ‘GetUtterancesView` operation to see the requests that they have made and whether they have been successful. You might find that the utterance “I want flowers” is not being recognized. You could add this utterance to the `OrderFlowers` intent so that your bot recognizes that utterance.
After you publish a new version of a bot, you can get information about the old version and the new so that you can compare the performance across the two versions.
Utterance statistics are generated once a day. Data is available for the last 15 days. You can request information for up to 5 versions of your bot in each request. Amazon Lex returns the most frequent utterances received by the bot in the last 15 days. The response contains information about a maximum of 100 utterances for each version.
If you set ‘childDirected` field to true when you created your bot, if you are using slot obfuscation with one or more slots, or if you opted out of participating in improving Amazon Lex, utterances are not available.
This operation requires permissions for the ‘lex:GetUtterancesView` action.
2762 2763 2764 2765 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2762 def get_utterances_view(params = {}, = {}) req = build_request(:get_utterances_view, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags associated with the specified resource. Only bots, bot aliases, and bot channels can have tags associated with them.
2794 2795 2796 2797 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 2794 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_bot(params = {}) ⇒ Types::PutBotResponse
Creates an Amazon Lex conversational bot or replaces an existing bot. When you create or update a bot you are only required to specify a name, a locale, and whether the bot is directed toward children under age 13. You can use this to add intents later, or to remove intents from an existing bot. When you create a bot with the minimum information, the bot is created or updated but Amazon Lex returns the ‘ response FAILED. You can build the bot after you add one or more intents. For more information about Amazon Lex bots, see how-it-works. </p> If you specify the name of an existing bot, the fields in the request replace the existing values in the $LATEST version of the bot. Amazon Lex removes any fields that you don’t provide values for in the request, except for the idleTTLInSeconds and privacySettings fields, which are set to their default values. If you don’t specify values for required fields, Amazon Lex throws an exception. This operation requires permissions for the lex:PutBot action. For more information, see security-iam. ‘
3271 3272 3273 3274 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 3271 def put_bot(params = {}, = {}) req = build_request(:put_bot, params) req.send_request() end |
#put_bot_alias(params = {}) ⇒ Types::PutBotAliasResponse
Creates an alias for the specified version of the bot or replaces an alias for the specified bot. To change the version of the bot that the alias points to, replace the alias. For more information about aliases, see versioning-aliases.
This operation requires permissions for the ‘lex:PutBotAlias` action.
3379 3380 3381 3382 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 3379 def put_bot_alias(params = {}, = {}) req = build_request(:put_bot_alias, params) req.send_request() end |
#put_intent(params = {}) ⇒ Types::PutIntentResponse
Creates an intent or replaces an existing intent.
To define the interaction between the user and your bot, you use one or more intents. For a pizza ordering bot, for example, you would create an ‘OrderPizza` intent.
To create an intent or replace an existing intent, you must provide the following:
-
Intent name. For example, ‘OrderPizza`.
-
Sample utterances. For example, “Can I order a pizza, please.” and “I want to order a pizza.”
-
Information to be gathered. You specify slot types for the information that your bot will request from the user. You can specify standard slot types, such as a date or a time, or custom slot types such as the size and crust of a pizza.
-
How the intent will be fulfilled. You can provide a Lambda function or configure the intent to return the intent information to the client application. If you use a Lambda function, when all of the intent information is available, Amazon Lex invokes your Lambda function. If you configure your intent to return the intent information to the client application.
You can specify other optional information in the request, such as:
-
A confirmation prompt to ask the user to confirm an intent. For example, “Shall I order your pizza?”
-
A conclusion statement to send to the user after the intent has been fulfilled. For example, “I placed your pizza order.”
-
A follow-up prompt that asks the user for additional activity. For example, asking “Do you want to order a drink with your pizza?”
If you specify an existing intent name to update the intent, Amazon Lex replaces the values in the ‘$LATEST` version of the intent with the values in the request. Amazon Lex removes fields that you don’t provide in the request. If you don’t specify the required fields, Amazon Lex throws an exception. When you update the ‘$LATEST` version of an intent, the `status` field of any bot that uses the `$LATEST` version of the intent is set to `NOT_BUILT`.
For more information, see how-it-works.
This operation requires permissions for the ‘lex:PutIntent` action.
4084 4085 4086 4087 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4084 def put_intent(params = {}, = {}) req = build_request(:put_intent, params) req.send_request() end |
#put_slot_type(params = {}) ⇒ Types::PutSlotTypeResponse
Creates a custom slot type or replaces an existing custom slot type.
To create a custom slot type, specify a name for the slot type and a set of enumeration values, which are the values that a slot of this type can assume. For more information, see how-it-works.
If you specify the name of an existing slot type, the fields in the request replace the existing values in the ‘$LATEST` version of the slot type. Amazon Lex removes the fields that you don’t provide in the request. If you don’t specify required fields, Amazon Lex throws an exception. When you update the ‘$LATEST` version of a slot type, if a bot uses the `$LATEST` version of an intent that contains the slot type, the bot’s ‘status` field is set to `NOT_BUILT`.
This operation requires permissions for the ‘lex:PutSlotType` action.
4278 4279 4280 4281 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4278 def put_slot_type(params = {}, = {}) req = build_request(:put_slot_type, params) req.send_request() end |
#start_import(params = {}) ⇒ Types::StartImportResponse
Starts a job to import a resource to Amazon Lex.
4355 4356 4357 4358 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4355 def start_import(params = {}, = {}) req = build_request(:start_import, params) req.send_request() end |
#start_migration(params = {}) ⇒ Types::StartMigrationResponse
Starts migrating a bot from Amazon Lex V1 to Amazon Lex V2. Migrate your bot when you want to take advantage of the new features of Amazon Lex V2.
For more information, see [Migrating a bot] in the *Amazon Lex developer guide*.
4439 4440 4441 4442 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4439 def start_migration(params = {}, = {}) req = build_request(:start_migration, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. If a tag key already exists, the existing value is replaced with the new value.
4473 4474 4475 4476 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4473 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a bot, bot alias or bot channel.
4501 4502 4503 4504 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4501 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4530 4531 4532 |
# File 'lib/aws-sdk-lexmodelbuildingservice/client.rb', line 4530 def waiter_names [] end |