Class: Aws::LexModelBuildingService::Types::BotChannelAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Represents an association between an Amazon Lex bot and an external messaging platform.

Constant Summary collapse

SENSITIVE =
[:bot_configuration]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_aliasString

An alias pointing to the specific version of the Amazon Lex bot to which this association is being made.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#bot_configurationHash<String,String>

Provides information necessary to communicate with the messaging platform.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#bot_nameString

The name of the Amazon Lex bot to which this association is being made.

<note markdown=“1”> Currently, Amazon Lex supports associations with Facebook and Slack, and Twilio.

</note>


153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#created_dateTime

The date that the association between the Amazon Lex bot and the channel was created.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#descriptionString

A text description of the association you are creating.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#failure_reasonString

If status is FAILED, Amazon Lex provides the reason that it failed to create the association.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#nameString

The name of the association between the bot and the channel.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#statusString

The status of the bot channel.

  • CREATED - The channel has been created and is ready for use.

  • IN_PROGRESS - Channel creation is in progress.

  • FAILED - There was an error creating the channel. For information about the reason for the failure, see the failureReason field.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end

#typeString

Specifies the type of association by indicating the type of channel being established between the Amazon Lex bot and the external messaging platform.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 153

class BotChannelAssociation < Struct.new(
  :name,
  :description,
  :bot_alias,
  :bot_name,
  :created_date,
  :type,
  :bot_configuration,
  :status,
  :failure_reason)
  SENSITIVE = [:bot_configuration]
  include Aws::Structure
end