Class: Aws::LexModelBuildingService::Types::CreateIntentVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumString

Checksum of the intent version created.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#conclusion_statementTypes::Statement

After the Lambda function specified in the fulfillmentActivity field fulfills the intent, Amazon Lex conveys this statement to the user.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_promptTypes::Prompt

If defined, the prompt that Amazon Lex uses to confirm the user's intent before fulfilling it.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date that the intent was created.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_code_hookTypes::CodeHook

If defined, Amazon Lex invokes this Lambda function for each user input.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#follow_up_promptTypes::FollowUpPrompt

If defined, Amazon Lex uses this prompt to solicit additional user activity after the intent is fulfilled.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_activityTypes::FulfillmentActivity

Describes how the intent is fulfilled.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#input_contextsArray<Types::InputContext>

An array of InputContext objects that lists the contexts that must be active for Amazon Lex to choose the intent in a conversation with the user.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configurationTypes::KendraConfiguration

Configuration information, if any, for connecting an Amazon Kendra index with the AMAZON.KendraSearchIntent intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_dateTime

The date that the intent was updated.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#output_contextsArray<Types::OutputContext>

An array of OutputContext objects that lists the contexts that the intent activates when the intent is fulfilled.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#parent_intent_signatureString

A unique identifier for a built-in intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#rejection_statementTypes::Statement

If the user answers "no" to the question defined in confirmationPrompt, Amazon Lex responds with this statement to acknowledge that the intent was canceled.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterancesArray<String>

An array of sample utterances configured for the intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#slotsArray<Types::Slot>

An array of slot types that defines the information required to fulfill the intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version number assigned to the new version of the intent.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 622

class CreateIntentVersionResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end