Class: Aws::LexModelBuildingService::Types::GetExportResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_statusString

The status of the export.

  • IN_PROGRESS - The export is in progress.

  • READY - The export is complete.

  • FAILED - The export could not be completed.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#export_typeString

The format of the exported data.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If status is FAILED, Amazon Lex provides the reason that it failed to export the resource.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the bot being exported.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the exported resource.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

An S3 pre-signed URL that provides the location of the exported resource. The exported resource is a ZIP archive that contains the exported resource in JSON format. The structure of the archive may change. Your code should not rely on the archive structure.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the bot being exported.



1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1740

class GetExportResponse < Struct.new(
  :name,
  :version,
  :resource_type,
  :export_type,
  :export_status,
  :failure_reason,
  :url)
  SENSITIVE = []
  include Aws::Structure
end