Class: Aws::LexModelBuildingService::Types::GetImportResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_dateTime

A timestamp for the date and time that the import job was created.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonArray<String>

A string that describes why an import job failed to complete.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#import_idString

The identifier for the specific import job.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#import_statusString

The status of the import job. If the status is FAILED, you can get the reason for the failure from the failureReason field.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#merge_strategyString

The action taken when there was a conflict between an existing resource and a resource in the import file.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name given to the import job.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource imported.



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796

class GetImportResponse < Struct.new(
  :name,
  :resource_type,
  :merge_strategy,
  :import_id,
  :import_status,
  :failure_reason,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end