Class: Aws::LexModelBuildingService::Types::GetSlotTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumString

Checksum of the ‘$LATEST` version of the slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date that the slot type was created.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#enumeration_valuesArray<Types::EnumerationValue>

A list of ‘EnumerationValue` objects that defines the values that the slot type can take.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_dateTime

The date that the slot type was updated. When you create a resource, the creation date and last update date are the same.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#parent_slot_type_signatureString

The built-in slot type used as a parent for the slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#slot_type_configurationsArray<Types::SlotTypeConfiguration>

Configuration information that extends the parent built-in slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#value_selection_strategyString

The strategy that Amazon Lex uses to determine the value of the slot. For more information, see PutSlotType.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the slot type.



2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 2252

class GetSlotTypeResponse < Struct.new(
  :name,
  :description,
  :enumeration_values,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :value_selection_strategy,
  :parent_slot_type_signature,
  :slot_type_configurations)
  SENSITIVE = []
  include Aws::Structure
end