Class: Aws::LexModelBuildingService::Types::PutIntentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lexmodelbuildingservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksumString

Checksum of the $LATESTversion of the intent created or updated.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#conclusion_statementTypes::Statement

After the Lambda function specified in thefulfillmentActivityintent fulfills the intent, Amazon Lex conveys this statement to the user.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_promptTypes::Prompt

If defined in the intent, Amazon Lex prompts the user to confirm the intent before fulfilling it.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#create_versionBoolean

True if a new version of the intent was created. If the createVersion field was not specified in the request, the createVersion field is set to false in the response.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date that the intent was created.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#dialog_code_hookTypes::CodeHook

If defined in the intent, Amazon Lex invokes this Lambda function for each user input.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#follow_up_promptTypes::FollowUpPrompt

If defined in the intent, Amazon Lex uses this prompt to solicit additional user activity after the intent is fulfilled.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_activityTypes::FulfillmentActivity

If defined in the intent, Amazon Lex invokes this Lambda function to fulfill the intent after the user provides all of the information required by the intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#input_contextsArray<Types::InputContext>

An array of InputContext objects that lists the contexts that must be active for Amazon Lex to choose the intent in a conversation with the user.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_configurationTypes::KendraConfiguration

Configuration information, if any, required to connect to an Amazon Kendra index and use the AMAZON.KendraSearchIntent intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_dateTime

The date that the intent was updated. When you create a resource, the creation date and last update dates are the same.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#output_contextsArray<Types::OutputContext>

An array of OutputContext objects that lists the contexts that the intent activates when the intent is fulfilled.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#parent_intent_signatureString

A unique identifier for the built-in intent that this intent is based on.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#rejection_statementTypes::Statement

If the user answers "no" to the question defined in confirmationPrompt Amazon Lex responds with this statement to acknowledge that the intent was canceled.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#sample_utterancesArray<String>

An array of sample utterances that are configured for the intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#slotsArray<Types::Slot>

An array of intent slots that are configured for the intent.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the intent. For a new intent, the version is always $LATEST.

Returns:



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 3742

class PutIntentResponse < Struct.new(
  :name,
  :description,
  :slots,
  :sample_utterances,
  :confirmation_prompt,
  :rejection_statement,
  :follow_up_prompt,
  :conclusion_statement,
  :dialog_code_hook,
  :fulfillment_activity,
  :parent_intent_signature,
  :last_updated_date,
  :created_date,
  :version,
  :checksum,
  :create_version,
  :kendra_configuration,
  :input_contexts,
  :output_contexts)
  SENSITIVE = []
  include Aws::Structure
end