Class: Aws::LexModelBuildingService::Types::StartImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelBuildingService::Types::StartImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelbuildingservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
A timestamp for the date and time that the import job was requested.
-
#import_id ⇒ String
The identifier for the specific import job.
-
#import_status ⇒ String
The status of the import job.
-
#merge_strategy ⇒ String
The action to take when there is a merge conflict.
-
#name ⇒ String
The name given to the import job.
-
#resource_type ⇒ String
The type of resource to import.
-
#tags ⇒ Array<Types::Tag>
A list of tags added to the imported bot.
Instance Attribute Details
#created_date ⇒ Time
A timestamp for the date and time that the import job was requested.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The identifier for the specific import job.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The status of the import job. If the status is FAILED, you can get the reason for the failure using the GetImport operation.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#merge_strategy ⇒ String
The action to take when there is a merge conflict.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name given to the import job.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource to import.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags added to the imported bot.
4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 4286 class StartImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :tags, :created_date) SENSITIVE = [] include Aws::Structure end |