Class: Aws::LexModelBuildingService::Types::Tag
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelBuildingService::Types::Tag
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelbuildingservice/types.rb
Overview
A list of key/value pairs that identify a bot, bot alias, or bot channel. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The key for the tag.
-
#value ⇒ String
The value associated with a key.