Class: Aws::LexModelBuildingService::Types::GetImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LexModelBuildingService::Types::GetImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lexmodelbuildingservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
A timestamp for the date and time that the import job was created.
-
#failure_reason ⇒ Array<String>
A string that describes why an import job failed to complete.
-
#import_id ⇒ String
The identifier for the specific import job.
-
#import_status ⇒ String
The status of the import job.
-
#merge_strategy ⇒ String
The action taken when there was a conflict between an existing resource and a resource in the import file.
-
#name ⇒ String
The name given to the import job.
-
#resource_type ⇒ String
The type of resource imported.
Instance Attribute Details
#created_date ⇒ Time
A timestamp for the date and time that the import job was created.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ Array<String>
A string that describes why an import job failed to complete.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The identifier for the specific import job.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The status of the import job. If the status is FAILED, you can get the reason for the failure from the failureReason field.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#merge_strategy ⇒ String
The action taken when there was a conflict between an existing resource and a resource in the import file.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name given to the import job.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource imported.
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 |
# File 'lib/aws-sdk-lexmodelbuildingservice/types.rb', line 1796 class GetImportResponse < Struct.new( :name, :resource_type, :merge_strategy, :import_id, :import_status, :failure_reason, :created_date) SENSITIVE = [] include Aws::Structure end |